@@ -80,7 +80,7 @@ ATTDICT = {
     "R": "float",
     "L": "bool",
     "E": "unsigned int",
-    "X": "byte(s)",
+    "X": "byte(s) as hex string",
     "C": "char(s)",
 }
 
@@ -146,7 +146,7 @@ class UBX_CFGVAL_Frame(Frame):
         self._lbx_cat.config(xscrollcommand=self._scr_cath.set)
         self._scr_catv.config(command=self._lbx_cat.yview)
         self._scr_cath.config(command=self._lbx_cat.xview)
-        self._lbl_parm = Label(self, text="Parameter", anchor="w")
+        self._lbl_parm = Label(self, text="Keyname", anchor="w")
         self._lbx_parm = Listbox(
             self,
             border=2,
@@ -196,10 +196,10 @@ class UBX_CFGVAL_Frame(Frame):
         self._spn_layer = Spinbox(
             self,
             textvariable=self._cfglayer,
-            values=("RAM", "BBR", "FLASH"),
+            values=("RAM", "BBR", "FLASH", "DEFAULT"),
             bg=ENTCOL,
             wrap=True,
-            width=6,
+            width=8,
             state=READONLY,
             readonlybackground=ENTCOL,
         )
@@ -309,12 +309,13 @@ class UBX_CFGVAL_Frame(Frame):
         Config interface send button has been clicked.
         """
 
-        if self._cfgmode.get() == VALSET:
-            self._do_valset()
-        elif self._cfgmode.get() == VALDEL:
-            self._do_valdel()
-        else:
-            self._do_valget()
+        if self._cfgval_keyname is not None:
+            if self._cfgmode.get() == VALSET:
+                self._do_valset()
+            elif self._cfgmode.get() == VALDEL:
+                self._do_valdel()
+            else:
+                self._do_valget()
 
     def _do_valset(self):
         """
@@ -399,6 +400,7 @@ class UBX_CFGVAL_Frame(Frame):
         ]
         msg = UBXMessage.config_del(layers, transaction, key)
         self.__app.serial_handler.serial_write(msg.serialize())
+        self._ent_val.configure(bg=ENTCOL)
         self._lbl_send_command.config(image=self._img_pending)
         self.__container.set_status("CFG-VALDEL SET message sent", "blue")
         self.__container.set_pending(UBX_CFGVAL, ("ACK-ACK", "ACK-NAK"))
@@ -413,6 +415,8 @@ class UBX_CFGVAL_Frame(Frame):
             layers = 1
         elif layers == "FLASH":
             layers = 2
+        elif layers == "DEFAULT":
+            layers = 7
         else:
             layers = 0
         transaction = 0
@@ -421,6 +425,7 @@ class UBX_CFGVAL_Frame(Frame):
         ]
         msg = UBXMessage.config_poll(layers, transaction, keys)
         self.__app.serial_handler.serial_write(msg.serialize())
+        self._ent_val.configure(bg=ENTCOL)
         self._lbl_send_command.config(image=self._img_pending)
         self.__container.set_status("CFG-VALGET POLL message sent", "blue")
         self.__container.set_pending(UBX_CFGVAL, ("CFG-VALGET", "ACK-ACK", "ACK-NAK"))
@@ -430,7 +435,17 @@ class UBX_CFGVAL_Frame(Frame):
         Update pending confirmation status.
         """
 
-        if cfgtype in ("ACK-ACK", "CFG-VALGET"):
+        if cfgtype == "CFG-VALGET":
+            self._lbl_send_command.config(image=self._img_confirmed)
+            data = kwargs.get("data", None)
+            if data is not None:
+                val = getattr(data, self._cfgval_keyname, None)
+                if val is not None:
+                    if isinstance(val, bytes):
+                        val = val.hex()
+                    self._cfgval.set(val)
+            self.__container.set_status(f"{cfgtype} GET message received", "green")
+        elif cfgtype == "ACK-ACK":
             self._lbl_send_command.config(image=self._img_confirmed)
             self.__container.set_status(f"{cfgtype} GET message received", "green")
         elif cfgtype == "ACK-NAK":
